# Create your views here.
from django.shortcuts import render_to_response, get_object_or_404
from django.http import HttpResponse
from django.utils import simplejson as json
from django import forms
import deploy

from smtplib import SMTPException

def homepage(request):
    return render_to_response('index.html', {})

def static_view(request, template_name):
    return render_to_response(template_name, {})


class ContactForm(forms.Form):
    subject = forms.CharField(max_length=100)
    message = forms.CharField(widget=forms.widgets.Textarea())
    sender = forms.EmailField()

def contactpost(req):
    """
    Sends email if possible.
    returns form, status
    """
    
    status = None
    form = ContactForm(req.POST) # A form bound to the POST data
    
    if form.is_valid(): # All validation rules pass
        subject = form.cleaned_data['subject']
        message = form.cleaned_data['message']
        sender = form.cleaned_data['sender']
        recipients = [deploy.EMAIL_CONTACT_RECIPIENT]
    
        from django.core.mail import EmailMessage
        
        try:
            em = EmailMessage(subject, message, deploy.EMAIL_CONTACT_SENDER, recipients, headers = {'Reply-To': sender})
            em.send()
            status = { 'good': True, 'msg':"" }
        except SMTPException, ex:
            status = { 'good': False, 'msg':str(ex) }
        
    return form, status
    
        
def contactpost_async(req):
    """
    returns json: {good: True|False, msg:'somestr'}
    """
    
    form, status = contactpost(req)
    return HttpResponse(json.dumps(status))


def contact(req):
    if req.method == 'POST':
        if req.POST.has_key('async'):
            return contactpost_async(req)
            
        form, status = contactpost(req)

    else:
        status = None
        form = ContactForm()
    
    return render_to_response('contact.html', {'form': form, 'status':status})
